Class: Aws::MarketplaceCommerceAnalytics::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceCommerceAnalytics::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacecommerceanalytics/client.rb
Overview
An API client for MarketplaceCommerceAnalytics. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MarketplaceCommerceAnalytics::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#generate_data_set(params = {}) ⇒ Types::GenerateDataSetResult
Given a data set type and data set publication date, asynchronously publishes the requested data set to the specified S3 bucket and notifies the specified SNS topic once the data is available.
-
#start_support_data_export(params = {}) ⇒ Types::StartSupportDataExportResult
*This target has been deprecated.* Given a data set type and a from date, asynchronously publishes the requested customer support data to the specified S3 bucket and notifies the specified SNS topic once the data is available.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-marketplacecommerceanalytics/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
756 757 758 |
# File 'lib/aws-sdk-marketplacecommerceanalytics/client.rb', line 756 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
759 760 761 |
# File 'lib/aws-sdk-marketplacecommerceanalytics/client.rb', line 759 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 |
# File 'lib/aws-sdk-marketplacecommerceanalytics/client.rb', line 729 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceCommerceAnalytics') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplacecommerceanalytics' context[:gem_version] = '1.89.0' Seahorse::Client::Request.new(handlers, context) end |
#generate_data_set(params = {}) ⇒ Types::GenerateDataSetResult
Given a data set type and data set publication date, asynchronously publishes the requested data set to the specified S3 bucket and notifies the specified SNS topic once the data is available. Returns a unique request identifier that can be used to correlate requests with notifications from the SNS topic. Data sets will be published in comma-separated values (CSV) format with the file name data_set_type_YYYY-MM-DD.csv. If a file with the same name already exists (e.g. if the same data set is requested twice), the original file will be overwritten by the new file. Requires a Role with an attached permissions policy providing Allow permissions for the following actions: s3:PutObject, s3:GetBucketLocation, sns:GetTopicAttributes, sns:Publish, iam:GetRolePolicy.
651 652 653 654 |
# File 'lib/aws-sdk-marketplacecommerceanalytics/client.rb', line 651 def generate_data_set(params = {}, = {}) req = build_request(:generate_data_set, params) req.send_request() end |
#start_support_data_export(params = {}) ⇒ Types::StartSupportDataExportResult
*This target has been deprecated.* Given a data set type and a from date, asynchronously publishes the requested customer support data to the specified S3 bucket and notifies the specified SNS topic once the data is available. Returns a unique request identifier that can be used to correlate requests with notifications from the SNS topic. Data sets will be published in comma-separated values (CSV) format with the file name data_set_type_YYYY-MM-DD’T’HH-mm-ss’Z’.csv. If a file with the same name already exists (e.g. if the same data set is requested twice), the original file will be overwritten by the new file. Requires a Role with an attached permissions policy providing Allow permissions for the following actions: s3:PutObject, s3:GetBucketLocation, sns:GetTopicAttributes, sns:Publish, iam:GetRolePolicy.
720 721 722 723 |
# File 'lib/aws-sdk-marketplacecommerceanalytics/client.rb', line 720 def start_support_data_export(params = {}, = {}) req = build_request(:start_support_data_export, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
749 750 751 |
# File 'lib/aws-sdk-marketplacecommerceanalytics/client.rb', line 749 def waiter_names [] end |